@@ -14,21 +14,30 @@ use Sys::Syslog;
 use Errorlog::TeeOutput;
 
 
-my $version ='$Id: Errorlog.pm 14037 2007-09-12 08:28:37Z anton $ ';
-our $VERSION="1.22";
+my $version ='$Id: Errorlog.pm 24757 2008-05-30 10:44:29Z anton $ ';
+our $VERSION="1.25";
 #global variable, needed for TeeOutput
 our $SELF;
 
+
+sub end
+{
+  warn "Exitcode: $?";
+  if ($SELF->{fields}->{mailonfailure})
+  {
+    my $logbuffer=$SELF->{fields}->{logbuffer} if ($SELF->{fields}->{logbuffer});
+    $SELF->mail("Errorlog v$VERSION failure: Errorstatus: $?, \n$logbuffer") ;
+  }
+}
+
 END
 {
+  return if ($SELF->{fields}->{skipEND});
   if ($?)
   {
-    warn "Exitcode: $?";
-    if ($SELF->{fields}->{mailonfailure})
-    {
-      my $logbuffer=$SELF->{fields}->{logbuffer} if ($SELF->{fields}->{logbuffer});
-      $SELF->mail("Errorlog v$VERSION failure: Errorstatus: $?, \n$logbuffer") ;
-    }
+    # call shutdown to be able to call this method from an eternally living
+    # perl interpretor such as modperl.
+    end();
   }
 }
 
@@ -77,22 +86,24 @@ sub new
 		  'hirestimer'=>0,
                   'user'=>$user,
 		  'version'=>$VERSION,
+		  'skipEND'=>'',
 		}
 		);
 
   #note: modified version of field is called
   $self->fields(@_);
-  if ($configdir)
+
+  if ($self->{fields}->{configdir})
   {
-    unless ( -d $configdir )
+    unless ( -d $self->{fields}->{configdir} )
     {
-      carp "Warning configdir: \"$configdir\" does not exist";
+      carp "Warning configdir: \"$self->{fields}->{configdir}\" does not exist";
     }
   }
-#  else
-#  {
-#    warn "No configdir specified";
-#  }
+  else
+  {
+    warn "No configdir specified";
+  }
 
   $self->overrule();
   if ($self->error())
@@ -175,6 +186,7 @@ sub new
 
   openTee (*STDERR,@params,\%params);
   carp "Entering logmode for: $0 " if (verbosity() >=2 );
+  carp ("configdir: $self->{fields}->{configdir}");
 
   return $self;
 }
@@ -231,6 +243,7 @@ sub field
 
 
 #NOTE NO self
+
 sub teecallback
 {
   my $hiRes='';
@@ -241,7 +254,7 @@ sub teecallback
   my $longmess="";
 
   #assignement should not be necessary, but it is..
-  (@string) = map {  s/\n$//g; $_.="\n" } grep /./, @string;
+  (@string) = map {  s/\x0/\<NUL\>/g ;s/\n$//g; $_.="\n" } grep m{.}, @string;
 
   if ($fh eq 'syslog')
   {
@@ -254,13 +267,13 @@ sub teecallback
     }
     foreach my $string (@string)
     {
-      foreach my $substr (split ("\n",$string))
+      foreach my $substr (split (/\n/,$string))
       {
 	next unless ($substr);
+#	$substr.="\n" unless ($substr =~ /\n/);
 #	next if ($substr =~ /^\W*$/);
 #       syslog $priority, $format, @args
-#           If $priority permits, logs ($format, @args) printed as by "printf(3V)", with the addition that %m is replaced with "$!" (the lat-
-#           est error message).
+#           If $priority permits, logs ($format, @args) printed as by "printf(3V)", with the addition that %m is replaced with "$!" (the latest error message).
 	my $blocksize=$SELF->{fields}->{syslogmaxbuf};
 
 	if (length ($substr) > $blocksize)
@@ -545,7 +558,7 @@ sub overrule
 	chomp;
 
 	my ($name,$split,$value) = split /\s*([=\|])\s*/;
-	my @values = split /,/, $value;
+	my @values = split (/,/, $value);
 #      warn $self->inspect($name, $value, $split,\@values);
 
 	if ($name eq 'verbosity')
